#
# spec file for package yara
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 3
Name:           yara
Version:        3.6.1
Release:        lp151.2.3
Summary:        A malware identification and classification tool
License:        Apache-2.0
Group:          System/Filesystems
Url:            http://plusvic.github.io/yara/
Source:         https://github.com/VirusTotal/yara/archive/v%{version}.tar.gz
BuildRequires:  file-devel
BuildRequires:  flex
BuildRequires:  libjansson-devel
BuildRequires:  libtool
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
YARA is a tool aimed at helping malware researchers to identify and classify malware samples. With YARA you can create descriptions of malware families based on textual or binary patterns contained on samples of those families. Each description consists of a set of strings and a Boolean expression which determines its logic. Let's see an example:

%package -n libyara%{soname}
Summary:        Library to support the yara malware identification tool
Group:          System/Libraries

%description -n libyara%{soname}
YARA is a tool aimed at helping malware researchers to identify and classify malware samples. With YARA you can create descriptions of malware families based on textual or binary patterns contained on samples of those families. Each description consists of a set of strings and a Boolean expression which determines its logic. Let's see an example:

%package -n python-%name
Summary:        Python bindings to support the yara malware identification tool
Group:          Development/Languages/Python
Requires:       python

%description -n python-%name
YARA is a tool aimed at helping malware researchers to identify and classify malware samples. With YARA you can create descriptions of malware families based on textual or binary patterns contained on samples of those families. Each description consists of a set of strings and a Boolean expression which determines its logic. Let's see an example:

%package -n libyara-devel
Summary:        Development files to support the yara malware identification tool
Group:          Development/Libraries/C and C++
Requires:       libyara%{soname} = %{version}-%{release}

%description -n libyara-devel
YARA is a tool aimed at helping malware researchers to identify and classify malware samples. With YARA you can create descriptions of malware families based on textual or binary patterns contained on samples of those families. Each description consists of a set of strings and a Boolean expression which determines its logic. Let's see an example:

%package doc
Summary:        Documentation files to support the YARA malware identification tool
Group:          Development/Libraries/C and C++
Requires:       libyara%{soname} = %{version}-%{release}

%description doc
Documentation and guideslines to support YARA.

YARA is a tool aimed at helping malware researchers to identify and classify malware samples. With YARA you can create descriptions of malware families based on textual or binary patterns contained on samples of those families. Each description consists of a set of strings and a Boolean expression which determines its logic. Let's see an example:

%prep
%setup -q

%build
./bootstrap.sh
# cuckoo depends on libjansson-devel: not in factory
%if 0%{?suse_version} > 1310
%configure --enable-magic --enable-cuckoo
%else
%configure --enable-magic
%endif
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name '*.la' -delete -print
find %{buildroot} -type f -name '*.a' -delete -print

%post   -n libyara%{soname} -p /sbin/ldconfig
%postun -n libyara%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING README.md CONTRIBUTORS AUTHORS
%{_bindir}/yara
%{_bindir}/yarac
%{_mandir}/man1/yara.1.gz
%{_mandir}/man1/yarac.1.gz

%files -n libyara%{soname}
%defattr(-,root,root)
%doc COPYING README.md CONTRIBUTORS AUTHORS
%{_libdir}/libyara.so.3
%{_libdir}/libyara.so.%{version}

%files -n libyara-devel
%defattr(-,root,root)
%doc COPYING README.md CONTRIBUTORS AUTHORS 
%{_includedir}/yara.h
%{_includedir}/yara
%{_libdir}/libyara.so
%{_libdir}/pkgconfig/yara.pc

%files doc
%defattr(-,root,root)
%doc docs

%changelog
* Tue Jun  6 2017 Greg.Freemyer@gmail.com
- update to v3.6.1
  * BUGFIX: Stack overflow caused by uncontrolled recursiveness (CVE-2017-9304)
  * BUGFIX: pe.overlay.size was undefined if the PE didn't have an overlay. Now it's set to 0 in those cases.
  * BUGFIX: Fix initalization issue that could cause a crash if rules compiled with a 32bit yarac is used with a 64bit yara.
- update to v3.6.0
  * .NET module (Wesley Shields)
  * New features for ELF module (Jacob Baines)
  * Fix endianness issues (Hilko Bengen)
  * Function yr_compiler_add_fd added to libyara
  * MAX_THREADS limit can be arbitrarily increased (Emerson R. Wiley)
  * Added --fail-on-warnings command-line option
  * Multiple bug fixes:
  CVE-2016-10210, CVE-2016-10211, CVE-2017-5923, CVE-2017-5924,
  CVE-2017-8294, CVE-2017-8929, CVE-2017-9438
* Sat Nov 12 2016 jengelh@inai.de
- Add pkg-config to ensure .pc autodetection is always in effect
* Fri Sep 30 2016 Greg.Freemyer@gmail.com
- update to v3.5.0
  * Match length operator (http://yara.readthedocs.io/en/v3.5.0/writingrules.html#match-length)
  * Performance improvements
  * Less memory consumption while scanning processes
  * Exception handling when scanning memory blocks
  * Negative integers in meta fields
  * Added the --stack-size command-argument
  * Functions import_ordinal, is_dll, is_32bit and is_64bit added to PE module
  * Functions rich_signature.toolid and rich_signature.version added to PE module
  * Lots of bug fixes
- upstream moved python-yara into a separate project.  Do the same.
- python-plaso now requires python-yana >= v3.5.0
- add BuildRequires: pkg-config as documented in the openSUSE packaging guidelines
* Thu Jul 23 2015 Greg.Freemyer@gmail.com
- add yara.pc to the libyara subpackage
- remove sed command previously needed to properly link Yara and libyara.  No longer needed with latest upstream source.
- update to v3.4.0
  * Short-circuit evaluation for conditions
  * New yr_rules_save_stream/yr_rules_load_stream APIs.
  * load() and save() methods in yara-python accept file-like objects
  * Improvements to the PE and ELF modules
  * Some performance improvements
  * New command-line option --print-module-data
  * Multiple bug fixes.
- v3.3.0
  * Added support for negative integers and floating point numbers
  * Implemented operators >,<, >=, <= for strings
  * Implemented word boundary anchors (\b, \B) in regular expressions
  * New features in PE module
  * Math module
  * New --print-namespace command line argument
  * Better error handling in low memory conditions
  * BUGFIX: "at" operator not working with certain strings containing wildcards
  * BUGFIX: precedence of bitwise operators was incorrect
  * BUGFIX: incorrect imphash result for certain PE files importing functions by ordinal
  * BUGFIX: handle and memory leaks
  * BUGFIX: multiple segfaults
- v3.2.0
  * ELF module
  * Hash module
  * New features in PE module
  * Big-endian version of intXX and uintXX functions
  * Modules can declare dictionary objects
  * Modules accept overloaded functions
  * Performance improvements
  * BUGFIX: "and" operator not working properly with integer operands
  * BUGFIX: False positive with strings declared as "fullword wide ascii"
  * BUGFIX: False positive with "wide fullword" strings shorter than 5 bytes
  * BUGFIX: Functions declared in a structure array not working properly
  * BUGFIX: "contains" operator causing segfault if operand is an undefined string
* Fri Sep 26 2014 Greg.Freemyer@gmail.com
- split off a -doc sub-project
* Wed Sep 24 2014 Greg.Freemyer@gmail.com
- update to v3.1.0
  * Yara now supports plugin modules
  * Numerous major improvements.  See README.md in the documentation folder for details
- update License to Apache 2.0
- build with cuckoo and magic modules (cuckoo only for factory and newer)
- major specfile cleanup
  * add soname as a variable and use it appropriately
  * add /usr/bin/yarac and associated man file
  * update Url and Source fields
  * add libtool build requirement
  * delete no longer needed patch, now upstream: yara-fixes.patch
  * add ./bootstrap.sh call to %%build section as recommended by upstream
  * add +%%{_includedir}/yara to -devel since it is full of yara related header files
  * use default naming for devel sub-project
  * remove *.a and *.la files from the devel sub-project
  * incorporate python-yara as a sub-project
* Wed Feb 15 2012 Greg.Freemyer@gmail.com
- Release should have a value of zero in OBS.  It is handled automatically via OBS.
* Mon Feb 13 2012 Greg.Freemyer@gmail.com
- use %%{__make} macro
* Thu Feb  9 2012 meissner@suse.com
- built with default compile flags, fixed 2 small issues
* Tue Feb  7 2012 Greg.Freemyer@gmail.com
- Initial submission
  A malware identification and classification tool
